#
# spec file for package google-osconfig-agent
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global provider        github
%global provider_tld    com
%global project         GoogleCloudPlatform
%global repo            osconfig
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}

Name:           google-osconfig-agent
Version:        20211117.00
Release:        1.14.1
Summary:        Google Cloud Guest Agent
License:        Apache-2.0
Group:          System/Daemons
URL:            https://%{provider_prefix}
Source0:        %{repo}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        rpmlintrc
BuildRequires:  go1.15
Requires:       google-guest-configs
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  golang-packaging

%{go_nostrip}
%{go_provides}

%description
Google Cloud OSConfig Agent

%prep
%setup -q -n %{repo}-%{version}
%setup -q -D -T -a 1 -n %{repo}-%{version}

%build
%goprep %{import_path}
CGO_ENABLED=0 go build -ldflags="-s -w -X main.version=%{version}-%{release}" -mod=vendor -o google_osconfig_agent

%install
install -d %{buildroot}%{_bindir}
install -d %{buildroot}%{_sbindir}
install -d %{buildroot}/etc/osconfig
install -p -m 0755 google_osconfig_agent %{buildroot}%{_bindir}/google_osconfig_agent
install -d %{buildroot}%{_unitdir}
install -p -m 0644 %{name}.service %{buildroot}%{_unitdir}
for srv_name in %{buildroot}%{_unitdir}/*.service; do rc_name=$(basename -s '.service' $srv_name); ln -s service %{buildroot}%{_sbindir}/rc$rc_name; done

%pre
    %service_add_pre google-osconfig-agent.service

%preun
    %service_del_preun google-osconfig-agent.service

%post
    %service_add_post google-osconfig-agent.service

%postun
    %service_del_postun google-osconfig-agent.service

%files
%defattr(0644,root,root,0755)
%doc README.md
%license LICENSE THIRD_PARTY_LICENSES
%attr(0755,root,root) %{_bindir}/*
%attr(0755,root,root) %{_sbindir}/*
%{_unitdir}/%{name}.service

%changelog
* Tue Nov 30 2021 adrian.glaubitz@suse.com
- Update to version 20211117.00 (bsc#1193257, bsc#1193258)
  * Add retry logic for RegisterAgent (#404)
- from version 20211111.01
  * e2e_test: drop ubuntu 1604 image as its EOL (#403)
- from version 20211111.00
  * e2e_test: move to V1 api for OSPolicies (#397)
- from version 20211102.00
  * Fix context logging and fix label names (#400)
- from version 20211028.00
  * Add cloudops example for gcloud (#399)
* Fri Oct 22 2021 adrian.glaubitz@suse.com
- Update to version 20211021.00
  * Added patch report logging for Zypper. (#395)
- from version 20211012.00
  * Replace deprecated instance filters with the new filters (#394)
- from version 20211006.00
  * Added patch report log messages for Yum and Apt (#392)
- from version 20210930.00
  * Config: Add package info caching (#391)
- from version 20210928.00
  * Fixed the runWithPty function to set ctty to child's filedesc (#389)
- from version 20210927.00
  * e2e_tests: fix a test output mismatch (#390)
- from version 20210924.00
  * Fix some e2e test failures (#388)
- from version 20210923.02
  * Correctly check for folder existance in package upgrade (#387)
- from version 20210923.01
  * ReportInventory: Fix bug in deb/rpm inventory, reduce calls to append (#386)
- from version 20210923.00
  * Deprecate old config directory in favor of new cache directory (#385)
- from version 20210922.02
  * Fix rpm/deb package formating for inventory reporting (#384)
- from version 20210922.01
  * Add centos stream rocky linux and available package tests (#383)
- from version 20210922.00
  * Add more info logs, actually cleanup unmanaged repos (#382)
- from version 20210901.00
  * Add E2E tests for Windows Application (#379)
  * Return lower-case package name (#377)
  * Update Terraform scripts for multi-project deployments tutorial. (#378)
- from version 20210811.00
  * Support Windows Application Inventory (#371)
- from version 20210723.00
  * Send basic inventory with RegisterAgent (#373)
- from version 20210722.1
  * e2e_tests: move to manually generated osconfig library (#372)
- from version 20210722.00
  * Create OWNERS file for examples directory (#368)
- from version 20210719.00
  * Update Zypper patch info parsing (#370)
* Tue Jul 27 2021 bwiedemann@suse.com
- Build with go1.15 for reproducible build results (boo#1102408)
* Mon Jul 19 2021 adrian.glaubitz@suse.com
- Update to version 20210712.1
  * Skip getting patch info when no patches are found. (#369)
- from version 20210712.00
  * Add Terraform scripts for multi-project deployments (#367)
- from version 20210709.00
  * Add examples/Terraform directory. (#366)
- from version 20210707.00
  * Fix bug in printing packages to update,
    return error for zypper patch (#365)
- from version 20210629.00
  * Add CloudOps examples for CentOS (#364)
* Wed Jun 23 2021 adrian.glaubitz@suse.com
- Update to version 20210621.00
  * chore: Fixing a comment. (#363)
- from version 20210617.00
  * Use exec.CommandContext so that canceling the context also
    kills any running processes (#362)
- from version 20210608.1
  * e2e_tests: point to official osconfig client library (#359)
- from version 20210608.00
  * e2e_tests: deflake tests (#358)
- from version 20210607.00
  * Fix build on some architectures (#357)
- from version 20210603.00
  * Create win-validation-powershell.yaml (#356)
- from version 20210602.00
  * Agent efficiency improvements/bugfixes/logging updates (#355)
  * e2e_tests: add tests for ExecResource output (#354)
- from version 20210525.00
  * Run fieldalignment on all structs (#353)
- from version 20210521.00
  * Config Task: add error message and ExecResource output recording (#350)
  * e2e_tests: remove Windows server 1909 and add server 20h2 (#352)
  * Added a method for logging structured data (#349)
* Tue May 11 2021 adrian.glaubitz@suse.com
- Update to version 20210506.00 (bsc#1185848, bsc#1185849)
  * Add more os policy assignment examples (#348)
  * e2e_tests: enable stable tests for OSPolicies (#347)
  * Align start and end task logs (#346)
  * ConfigTask: add additional info logs (#345)
  * e2e_tests: add validation tests (#344)
  * Config Task: make sure agent respects policy mode (#343)
  * update
  * e2e_tests: readd retries to OSPolicies
  * Set minWaitDuration as a string instead of object (#341)
  * e2e_tests: Fix a few SUSE tests (#339)
  * Remove pre-release flag from config (#340)
  * e2e_tests: fixup OSPolicy tests (#338)
  * e2e_tests: unlock mutex for CreatePolicies as soon as create finishes (#337)
  * e2e_tests: Don't retry failed OSPolicy tests, fix msi test (#336)
  * Examples for os policy assignments (#334)
  * e2e_tests: increase the deadline for OSPolicy tests and only start after a zone has been secured (#335)
  * Fix panic when installing MSI (#332)
  * e2e_tests: Add test cases of installing dbe, rpm and msi packages (#333)
  * e2e_tests: add more logging
  * e2e_tests: (#330)
  * e2e_test: Add timouts to OSPolicy tests so we don't wait forever (#329)
  * Create top level directories for gcloud and console for os policy assignment examples (#328)
  * e2e_tests: Move api from an internal directory (#327)
  * Make sure we use the same test name for reruns (#326)
  * Add CONFIG_V1 capability (#325)
  * e2e_tests: reduce size of instances, use pd-balanced, rerun failed tests once (#324)
  * Only report installed packages for dpkg (#322)
  * e2e_tests: fix windows package and repository tests (#323)
  * Add top level directories for os policy examples (#321)
  * e2e_tests: move to using inventory api for inventory reporting (#320)
  * e2e_tests: add ExecResource tests (#319)
  * ExecResource: make sure we set permissions correctly for downloaded files (#318)
  * Config task: only run post check on resources that have already been evaluated (#317)
  * e2e_test: reorganize OSPolicy tests to be per Resource type (#316)
  * Set custom user agent (#299)
  * e2e_tests: check InstanceOSPoliciesCompliance for each test case, add LocalPath FileResource test (#314)
  * PackageResource: make sure to run AptUpdate prior to package install (#315)
  * Fix bugs/add more logging for OSPolicies (#313)
  * Change metadata http client to ignore http proxies (#312)
  * e2e_test: add tests for FileResource (#311)
  * Add task_type context logging (#310)
  * Fix e2e_test typo (#309)
  * Fix e2e_tests (#308)
  * Disable OSPolicies by default since it is an unreleased feature (#307)
  * e2e_tests: Add more OSPolicies package and repo tests (#306)
  * Do not enforce repo_gpgcheck in guestpolicies (#305)
  * Gather inventory 3-5min after agent start (#303)
  * e2e_tests: add OSPolicies tests for package install (#302)
  * Add helpful error log if a service account is missing (#304)
  * OSPolicies: correct apt repo extension, remove yum/zypper gpgcheck override (#301)
  * Update cos library to parse new version of packages file (#300)
  * config_task: Rework config step logic (#296)
  * e2e_test: enable serial logs in cos to support ReportInventory test (#297)
* Wed Mar 31 2021 adrian.glaubitz@suse.com
- Update to version 20210316.00 (bsc#1183414, bsc#1183415)
  * ExecResource: fix bug in return code handling (#295)
  * Fix ExecResource permissions, add logs to fetcher (#294)
  * e2e_tests: Fix ubuntu proposed family (#293)
  * e2e_tests: add proposed debian images to head tests (#292)
  * Fix exec_resource for config task, add minimal unit test (#291)
  * Change util.WriteFile to AtomicWriteFileStream (#289)
  * Merge development branch into master (#288)
  * Create util.TempFile to work nicely with Windows (#287)
  * Fix copy step write (#286)
  * Fix error on linux lock (#285)
  * Ensure we cleanup on error in AtomicWrite (#284)
  * Make writes atomic, add unused "allowDowngrades" option
    to apt, fix a few recipe issues (#283)
  * update reviewers (#282)
  * update apt package lists before running installs (#281)
  * Simplify build tags for COS package (#280)
* Tue Jan 12 2021 adrian.glaubitz@suse.com
- Update to version 20210112.00
  * Fix builds for ppc and s390x (#274)
  * Minor updates to tests and additional debug logging (#272)
  * Add Ubuntu 2004 to tests (#271)
  * Make sure we stop tickers (#270)
  * Drop Windows 1903 and CentOS 6 from tests (#269)
  * Pin el6 tests to last published image as it is EOL (#267)
  * support cos (#266)
* Tue Nov 24 2020 adrian.glaubitz@suse.com
- Update to version 20201117.00 (bsc#1179031, bsc#1179032)
  * Ignore Unavailable erros on stream receive (#260)
  * Update test Windows images (#259)
  * update ReportInventory e2e test regexes (#255)
  * Don't return on a windows update error (#254)
  * use retryutil for ReportInventory calls (#253)
  * add additional debug logging for ReportInventory request payload for e2e tests (#252)
  * stop logging instance identity token as part of ReportInventory request and remove
    feature-flag setting in OSInventoryReporting e2e tests (#251)
  * complete ExecTask as no-op when the ExecStepConfig doesn't match the OS (#250)
  * Add software recipe tests for COS (#249)
  * remove feature flag for inventory reporting (#243)
  * Force yum to never colorize output (#247)
  * Add sleep after Unavailable errors for agentendpoint (#241)
  * Ensure we record epoch for rpm packages (#242)
  * Make inventory WUAUpdates call spawn a new process,
    retry on metadata unmarshal error (#239)
  * add debug logging for report inventory response (#240)
  * add initial e2e tests for inventory reporting (#237)
  * Report installed packages on COS (#236)
* Thu Oct  8 2020 adrian.glaubitz@suse.com
- Update to version 20200929.00
  * Merge inventory feature from development (#235)
  * Set full version during Windows build (#234)
- Remove Provides/Obsoletes for google-compute-engine-init
* Tue Sep 15 2020 adrian.glaubitz@suse.com
- Initial build (bsc#1176427, bsc#1178249, jsc#ECO-2702, jsc#PM-2203)
  + Version 20200908.00
